/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import * as e from "react";
import l from "prop-types";
import { ButtonGroup as Q, Button as d, Toolbar as Ye, ToolbarSpacer as et } from "@progress/kendo-react-buttons";
import { TextBox as tt, InputSeparator as ot, InputSuffix as at } from "@progress/kendo-react-inputs";
import { Pager as nt } from "@progress/kendo-react-data-tools";
import { Upload as rt } from "@progress/kendo-react-upload";
import { ComboBox as lt } from "@progress/kendo-react-dropdowns";
import { Loader as ct } from "@progress/kendo-react-indicators";
import { validatePackage as st, classNames as it, WatermarkOverlay as ut } from "@progress/kendo-react-common";
import { useLocalization as mt } from "@progress/kendo-react-intl";
import { zoomOutIcon as dt, zoomInIcon as gt, pointerIcon as ft, handIcon as ht, searchIcon as vt, folderOpenIcon as bt, downloadIcon as kt, printIcon as pt, convertLowercaseIcon as yt, arrowUpIcon as Ct, arrowDownIcon as Et, xIcon as St } from "@progress/kendo-svg-icons";
import "pdfjs-dist/build/pdf.worker.min.mjs";
import { packageMetadata as xt } from "./package-metadata.mjs";
import { Scroller as wt, SearchService as Zt, scrollToPage as X, removeChildren as z, loadPDF as Y, reloadDocument as Lt, goToNextSearchMatch as ee, goToPreviousSearchMatch as zt, currentPage as It, calculateZoomLevel as Nt, download as Tt, print as Pt, DEFAULT_ZOOM_LEVEL as Mt } from "@progress/kendo-pdfviewer-common";
import { messages as i, popupBlocked as te, zoomOut as oe, zoomIn as ae, zoomLevel as ne, enableSelection as re, enablePanning as le, search as I, open as ce, download as se, print as ie, matchCase as ue, searchOf as me, prevMatch as de, nextMatch as ge, close as fe, actualWidth as Rt, fitToWidth as Ft, fitToPage as Dt } from "./messages.mjs";
const ve = [
  "pager",
  "spacer",
  "zoomInOut",
  "zoom",
  "selection",
  "spacer",
  "search",
  "open",
  "download",
  "print"
], y = {
  minZoom: 0.5,
  maxZoom: 4,
  tools: [...ve],
  zoomRate: 0.25,
  zoomLevels: [
    { id: 1, priority: 1, value: 1, text: "Actual width", type: "ActualWidth", locationString: Rt },
    { id: 2, priority: 2, value: 1, text: "Fit to width", type: "FitToWidth", locationString: Ft },
    { id: 3, priority: 3, value: 1, text: "Fit to page", type: "FitToPage", locationString: Dt },
    { id: 4, priority: 4, value: 0.5, text: "50%", type: "" },
    { id: 5, priority: 5, value: 0.75, text: "75%", type: "" },
    { id: 6, priority: 100, value: 1, text: "100%", type: "" },
    { id: 7, priority: 7, value: 1.25, text: "125%", type: "" },
    { id: 8, priority: 8, value: 1.5, text: "150%", type: "" },
    { id: 9, priority: 9, value: 2, text: "200%", type: "" },
    { id: 10, priority: 10, value: 3, text: "300%", type: "" },
    { id: 11, priority: 11, value: 4, text: "400%", type: "" }
  ],
  defaultZoom: Mt
}, Ot = [
  ".k-toolbar > button",
  ".k-toolbar .k-combobox > input",
  ".k-toolbar .k-button-group > button",
  ".k-toolbar .k-pager > a",
  ".k-toolbar .k-pager input"
];
let he = 0;
function Bt() {
  return he++, he;
}
const At = (a, E) => a.priority > E.priority ? -1 : a.priority < E.priority ? 1 : 0, be = e.forwardRef((a, E) => {
  const ke = !st(xt, { component: "PDFViewer" }), {
    zoom: O,
    zoomLevels: B = y.zoomLevels,
    defaultZoom: N = y.defaultZoom,
    minZoom: T = y.minZoom,
    maxZoom: P = y.maxZoom,
    zoomRate: S = y.zoomRate
  } = a, s = mt(), c = e.useRef(null), [pe, x] = e.useState(N), g = O !== void 0 ? O : pe, C = B.slice().sort(At).find((o) => o.value === g) || {
    text: g * 100 + "%",
    value: g,
    id: g,
    locationString: ""
  };
  C.locationString && (C.text = s.toLanguageString(
    C.locationString,
    i[C.locationString]
  ));
  const [u, M] = e.useState(!1), [ye, f] = e.useState(!0), [w, A] = e.useState(0), [Z, V] = e.useState(!0), [Ce, W] = e.useState(!1), [b, R] = e.useState(0), [h, k] = e.useState(0), [p, K] = e.useState(!1), [F, U] = e.useState(""), t = e.useMemo(() => ({}), []);
  t.currentZoom = g, t.props = a;
  const j = e.useCallback((o) => {
    c.current && c.current.style.setProperty("--scale-factor", String(o));
  }, []), v = e.useRef(null), L = e.useRef(null);
  e.useImperativeHandle(
    v,
    () => ({
      get element() {
        return L.current;
      },
      props: a,
      get pages() {
        return t.pages;
      },
      get document() {
        return t.document;
      }
    }),
    []
  ), e.useImperativeHandle(E, () => v.current);
  const Ee = e.useCallback(() => {
    if (t.props.onLoad) {
      const o = { target: v.current };
      t.props.onLoad.call(void 0, o);
    }
  }, []), q = e.useCallback(
    (o, n, r) => {
      if (a.onDownload) {
        const m = {
          target: v.current,
          blob: o,
          fileName: n,
          saveOptions: r
        };
        return a.onDownload.call(void 0, m) === !1;
      }
      return !1;
    },
    [a.onDownload]
  ), Se = e.useCallback(() => {
    var o;
    t.scroller && t.scroller.destroy(), t.scroller = new wt((o = c.current) == null ? void 0 : o.parentNode, {
      filter: ".k-page",
      events: {}
    }), t.scroller.disablePanEventsTracking();
  }, []), xe = e.useCallback((o) => {
    const n = Array.from(o.querySelectorAll(".k-text-layer"));
    t.search = new Zt({
      textContainers: n || [],
      highlightClass: "k-search-highlight",
      highlightMarkClass: "k-search-highlight-mark",
      charClass: "k-text-char"
    });
  }, []);
  t.done = e.useCallback(({ pdfPages: o, pdfDoc: n, zoom: r }) => {
    t.document = n, t.pages = o, t.zoom = r, Se(), f(!1), M(!0), Ee(), c.current && X(c.current, 0);
  }, []), t.error = e.useCallback(
    (o) => {
      if (t.document = null, t.pages = [], f(!1), M(!1), a.onError) {
        const n = typeof o == "string" ? { message: o } : o, r = {
          error: n != null ? n : s.toLanguageString(te, i[te]),
          target: v.current
        };
        a.onError.call(void 0, r);
      }
    },
    [a.onError]
  ), e.useEffect(() => {
    c.current && (a.url || a.data || a.arrayBuffer ? (f(!0), z(c.current), Y({
      url: a.url,
      data: a.data,
      arrayBuffer: a.arrayBuffer,
      dom: c.current,
      zoom: t.currentZoom,
      done: t.done,
      error: t.error
    }), j(t.currentZoom)) : (t.document = null, t.pages = [], M(!1), f(!1), z(c.current)));
  }, [a.url, a.data, a.arrayBuffer]);
  const H = e.useCallback((o, n) => {
    c.current && (f(!0), z(c.current), Lt({
      pdfDoc: o,
      zoom: n,
      dom: c.current,
      done: (r) => {
        t.pages = r, t.zoom = n, f(!1);
      },
      error: t.error
    }));
  }, []);
  e.useEffect(() => {
    j(g), c.current && t.document && g !== t.zoom && H(t.document, g);
  }, [g, H]), e.useEffect(() => () => {
    t.scroller && t.scroller.destroy(), t.search && t.search.destroy(), t.document = null, t.pages = [];
  }, []);
  const we = e.useCallback(() => {
    W(!0), xe(c.current);
  }, []), Ze = e.useCallback(
    (o) => {
      const n = o.value, r = t.search.search({ text: n, matchCase: p });
      k(r.length ? 1 : 0), R(r.length), U(n);
    },
    [p]
  ), Le = e.useCallback(() => {
    const o = t.search.search({ text: F, matchCase: !p });
    k(o.length ? 1 : 0), R(o.length), K(!p);
  }, [p, F]), ze = e.useCallback(() => {
    ee(t), k(h + 1 > b ? 1 : h + 1);
  }, [h, b]), Ie = e.useCallback(() => {
    zt(t), k(h - 1 < 1 ? b : h - 1);
  }, [h, b]), $ = e.useCallback(() => {
    t.search.destroy(), k(0), R(0), K(!1), U(""), W(!1);
  }, []), Ne = e.useCallback(
    (o) => {
      o.key === "Enter" ? (o.preventDefault(), ee(t), k(h + 1 > b ? 1 : h + 1)) : o.key === "Escape" && $();
    },
    [h, b]
  ), Te = e.useCallback(
    (o) => {
      if (c.current) {
        const n = o.skip;
        X(c.current, n);
        const r = {
          page: n + 1,
          target: v.current,
          syntheticEvent: o.syntheticEvent
        };
        a.onPageChange && a.onPageChange.call(void 0, r);
      }
      A(o.skip);
    },
    [w, a.onPageChange]
  ), Pe = e.useCallback(
    (o) => {
      if (L.current) {
        const n = It(L.current);
        if (n !== w) {
          A(n);
          const r = {
            page: n + 1,
            target: v.current,
            syntheticEvent: o
          };
          a.onPageChange && a.onPageChange.call(void 0, r);
        }
      }
    },
    [w, a.onPageChange]
  ), Me = e.useCallback(
    (o) => {
      const n = Math.min(t.currentZoom + S, P);
      if (n !== t.currentZoom && t.document && (x(n), a.onZoom)) {
        const r = {
          zoom: n,
          target: v.current,
          syntheticEvent: o
        };
        a.onZoom.call(void 0, r);
      }
    },
    [S, P, a.onZoom]
  ), Re = e.useCallback(
    (o) => {
      const n = Math.max(t.currentZoom - S, T);
      if (n !== t.currentZoom && t.document && (x(n), a.onZoom)) {
        const r = {
          zoom: n,
          target: v.current,
          syntheticEvent: o
        };
        a.onZoom.call(void 0, r);
      }
    },
    [S, T, a.onZoom]
  ), Fe = e.useCallback(
    (o) => {
      const n = o.value === null ? { text: "100%", value: 1, id: 100 } : { ...o.value };
      if (n.value === void 0) {
        const m = parseFloat(n.text);
        typeof m == "number" && !Number.isNaN(m) ? n.value = m / 100 : n.value = 1;
      }
      let r = n ? Nt(n.value, n.type, t.currentZoom, c.current) : 1;
      if (r = Math.round(r * 100) / 100, t.currentZoom !== r && t.document && (x(r), a.onZoom)) {
        const m = {
          zoom: r,
          target: v.current,
          syntheticEvent: o.syntheticEvent
        };
        a.onZoom.call(void 0, m);
      }
    },
    [a.onZoom]
  ), De = e.useCallback(() => {
    t.scroller.disablePanEventsTracking(), V(!0);
  }, []), Oe = e.useCallback(() => {
    t.scroller.enablePanEventsTracking(), V(!1);
  }, []), Be = e.useCallback(() => {
    Tt(
      {
        pdf: t.document,
        error: t.error
      },
      a.saveFileName,
      a.saveOptions,
      q
    );
  }, [a.url, a.data, a.arrayBuffer, a.saveFileName, a.saveOptions, q]), Ae = e.useCallback(() => {
    f(!0);
    const o = (r) => {
      f(!1), t.error(r);
    }, n = () => {
      f(!1);
    };
    Pt(t.pages, n, o);
  }, []), Ve = e.useCallback(
    (o) => {
      const n = o.newState;
      n[0] && n[0].getRawFile && n[0].getRawFile().arrayBuffer().then((m) => {
        if (c.current) {
          f(!0), z(c.current);
          const D = t.props.zoom === void 0 ? N : t.props.zoom;
          Y({
            arrayBuffer: m,
            dom: c.current,
            zoom: D,
            done: t.done,
            error: t.error
          }), x(D);
        }
      });
    },
    [N]
  ), We = e.useCallback((o) => {
    const n = o.target;
    if (n instanceof Element && n.parentNode) {
      const r = n.closest(".k-toolbar"), m = r && r.querySelector(".k-upload input");
      m && m.click();
    }
  }, []), _ = ye && /* @__PURE__ */ e.createElement("div", { className: "k-loader-container k-loader-container-md k-loader-top" }, /* @__PURE__ */ e.createElement("div", { className: "k-loader-container-overlay k-overlay-light" }), /* @__PURE__ */ e.createElement("div", { className: "k-loader-container-inner " }, /* @__PURE__ */ e.createElement(ct, { size: "large" }))), Ke = /* @__PURE__ */ e.createElement(Q, { className: "k-toolbar-button-group k-button-group-solid" }, /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-group-start",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(oe, i[oe]),
      disabled: g <= T || !u,
      onClick: Re,
      icon: "zoom-out",
      svgIcon: dt
    }
  ), /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-group-end",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(ae, i[ae]),
      disabled: g >= P || !u,
      onClick: Me,
      icon: "zoom-in",
      svgIcon: gt
    }
  )), Ue = /* @__PURE__ */ e.createElement(
    lt,
    {
      className: "k-toolbar-combobox",
      disabled: !u,
      data: B.map((o) => ({
        ...o,
        text: o.locationString ? s.toLanguageString(o.locationString, i[o.locationString]) : o.text
      })),
      dataItemKey: "id",
      textField: "text",
      value: u ? C : null,
      allowCustom: !0,
      onChange: Fe,
      placeholder: s.toLanguageString(ne, i[ne])
    }
  ), je = /* @__PURE__ */ e.createElement(
    nt,
    {
      disabled: !u,
      previousNext: !0,
      type: "input",
      skip: w,
      take: 1,
      total: t.pages ? t.pages.length : 0,
      info: !1,
      onPageChange: Te
    }
  ), qe = /* @__PURE__ */ e.createElement(et, null), He = /* @__PURE__ */ e.createElement(Q, { className: "k-toolbar-button-group k-button-group-solid" }, /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-group-start",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(re, i[re]),
      icon: "pointer",
      svgIcon: ft,
      disabled: !u,
      togglable: !0,
      selected: Z && u,
      onClick: De
    }
  ), /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-group-end",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(le, i[le]),
      icon: "hand",
      svgIcon: ht,
      disabled: !u,
      togglable: !0,
      selected: !Z && u,
      onClick: Oe
    }
  )), $e = /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-toolbar-button",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(I, i[I]),
      icon: "search",
      svgIcon: vt,
      disabled: !u,
      onClick: we
    }
  ), _e = /* @__PURE__ */ e.createElement(e.Fragment, null, /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-toolbar-button",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(ce, i[ce]),
      icon: "folder-open",
      svgIcon: bt,
      onClick: We
    }
  ), /* @__PURE__ */ e.createElement("div", { style: { display: "none" } }, /* @__PURE__ */ e.createElement(
    rt,
    {
      restrictions: { allowedExtensions: [".pdf"] },
      onAdd: Ve,
      autoUpload: !1,
      defaultFiles: [],
      multiple: !1,
      accept: ".pdf,.PDF",
      withCredentials: !1
    }
  ))), Ge = /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-toolbar-button",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(se, i[se]),
      icon: "download",
      svgIcon: kt,
      disabled: !u,
      onClick: Be
    }
  ), Je = /* @__PURE__ */ e.createElement(
    d,
    {
      className: "k-toolbar-button",
      fillMode: "flat",
      themeColor: "base",
      title: s.toLanguageString(ie, i[ie]),
      icon: "print",
      svgIcon: pt,
      disabled: !u,
      onClick: Ae
    }
  ), Qe = {
    pager: je,
    spacer: qe,
    zoomInOut: Ke,
    zoom: Ue,
    selection: He,
    search: $e,
    open: _e,
    download: Ge,
    print: Je
  }, Xe = (a.tools || y.tools).map((o) => ({
    ...Qe[o],
    key: "toobar-tool-" + o + Bt()
  })), G = /* @__PURE__ */ e.createElement(Ye, { buttons: Ot }, ...Xe), J = /* @__PURE__ */ e.createElement(
    "div",
    {
      className: it("k-canvas k-pdf-viewer-canvas k-pos-relative k-overflow-auto", {
        "k-enable-text-select": Z,
        "k-enable-panning": !Z
      }),
      onScroll: Pe
    },
    Ce && /* @__PURE__ */ e.createElement("div", { className: "k-search-panel k-pos-sticky k-top-center" }, /* @__PURE__ */ e.createElement(
      tt,
      {
        value: F,
        onChange: Ze,
        placeholder: s.toLanguageString(I, i[I]),
        autoFocus: !0,
        onKeyDown: Ne,
        suffix: () => /* @__PURE__ */ e.createElement(e.Fragment, null, /* @__PURE__ */ e.createElement(ot, null), /* @__PURE__ */ e.createElement(at, null, /* @__PURE__ */ e.createElement(
          d,
          {
            icon: "convert-lowercase",
            svgIcon: yt,
            title: s.toLanguageString(ue, i[ue]),
            fillMode: "flat",
            togglable: !0,
            selected: p,
            onClick: Le
          }
        )))
      }
    ), /* @__PURE__ */ e.createElement("span", { className: "k-search-matches" }, /* @__PURE__ */ e.createElement("span", null, h), " ", s.toLanguageString(me, i[me]), /* @__PURE__ */ e.createElement("span", null, b)), /* @__PURE__ */ e.createElement(
      d,
      {
        title: s.toLanguageString(de, i[de]),
        fillMode: "flat",
        icon: "arrow-up",
        svgIcon: Ct,
        disabled: b === 0,
        onClick: Ie
      }
    ), /* @__PURE__ */ e.createElement(
      d,
      {
        title: s.toLanguageString(ge, i[ge]),
        fillMode: "flat",
        icon: "arrow-down",
        svgIcon: Et,
        disabled: b === 0,
        onClick: ze
      }
    ), /* @__PURE__ */ e.createElement(
      d,
      {
        title: s.toLanguageString(fe, i[fe]),
        fillMode: "flat",
        icon: "x",
        svgIcon: St,
        onClick: $
      }
    )),
    /* @__PURE__ */ e.createElement("div", { ref: c, className: "k-pdf-viewer-pages" })
  );
  return /* @__PURE__ */ e.createElement("div", { className: "k-pdf-viewer", style: a.style, ref: L }, a.onRenderLoader ? a.onRenderLoader.call(void 0, _ || null) : _, a.onRenderToolbar ? a.onRenderToolbar.call(void 0, G) : G, a.onRenderContent ? a.onRenderContent.call(void 0, J) : J, ke && /* @__PURE__ */ e.createElement(ut, null));
});
be.displayName = "KendoReactPDFViewer";
be.propTypes = {
  url: l.string,
  data: l.string,
  arrayBuffer: l.any,
  typedArray: l.any,
  style: l.object,
  saveFileName: l.string,
  saveOptions: l.object,
  tools: l.arrayOf(l.oneOf(ve).isRequired),
  zoomLevels: l.arrayOf(l.any),
  zoom: l.number,
  defaultZoom: l.number,
  minZoom: l.number,
  maxZoom: l.number,
  zoomRate: l.number,
  onError: l.func,
  onLoad: l.func,
  onDownload: l.func,
  onRenderToolbar: l.func,
  onRenderContent: l.func,
  onRenderLoader: l.func,
  onZoom: l.func
};
export {
  be as PDFViewer
};
